﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using Bose.Wearable;

public class AppController : MonoBehaviour {

    public  bool connected;

    private WearableControl wearableControl;

    int sensorSelected = 0;
    public float speed = 1f;
    private float waitingAmount;
    public Image waitingImage;

    public bool gameStarted = false;

    public GameObject rotRaft;
    public GameObject transRaft;
    public GameObject cameraObj;

    public TerrainCollider terCol;

    public GameObject potatoCounterPanel;
    public Text potatoCounterLabel;
    int potatosCounted;
    public bool goalReached;
    public bool gameFinished;

    public AudioClip[] audios;
    public AudioSource source;

    public Slider uiSlider;
    float life;

    public bool introPass;

    public void Start()
    {

        Debug.Log("Start");
        Input.gyro.enabled = true;

        introPass = false;
        life = 120f;
        uiSlider.value = 1f;
        potatosCounted = 0;
        gameFinished = false;
        connected = false;
        gameStarted = false;
        waitingAmount = 0f;
        wearableControl = WearableControl.Instance;
        wearableControl.DeviceConnected += OnDeviceConnected;
       
    }

    public void OnDeviceConnected(Device obj)
    {
        if (connected) return;
        source.clip = audios[0];
        source.Play();
        wearableControl.SetSensorUpdateInterval(SensorUpdateInterval.FortyMs);

        //wearableControl.GyroscopeSensor.Start();
        wearableControl.AccelerometerSensor.Start();
        //wearableControl.GameRotationSensor.Start();
        Debug.Log("Connected!");
        connected = true;
        terCol.enabled = true;

    }


    public void Update()
    {


        if (!connected || !introPass) return;

        if (gameFinished) return;

        if(!gameStarted)
        { 
                if(wearableControl.LastSensorFrame.acceleration.value.z > 1f)
                {
                    waitingAmount += Time.deltaTime;
                    waitingImage.fillAmount = waitingAmount / 1f;
                    waitingImage.gameObject.SetActive(true);

                if (waitingAmount >= 1f)
                    {
                    source.clip = audios[1];
                    source.Play();
                    waitingImage.fillAmount = 0;
                    gameStarted = true;
                    waitingImage.gameObject.SetActive(false);

                    wearableControl.AccelerometerSensor.Start();

                }

                }else
                {
                    waitingImage.fillAmount = 0;
                    waitingAmount = 0f;
                    waitingImage.gameObject.SetActive(false);
                }
            return;
        }

        if (goalReached) return;


        //Debug.Log("Eu:" + rotRaft.transform.eulerAngles+" acc.x "+ wearableControl.LastSensorFrame.acceleration.value.x);
        life -= Time.deltaTime;
        uiSlider.value = life / 120f;

        rotRaft.transform.eulerAngles = new Vector3(rotRaft.transform.rotation.eulerAngles.x, rotRaft.transform.rotation.eulerAngles.y, wearableControl.LastSensorFrame.acceleration.value.x * 5f);
        




        //raft.transform.position = new Vector3(raft.transform.position.x, -5.06f, raft.transform.position.z);



    }


    private void FixedUpdate()
    {
        //raft.transform.Translate(Input.GetAxis("Horizontal") * 2f * Time.deltaTime, 0f, 0f);
        //
        //gameStarted = true;introPass = true; cameraObj.transform.Translate(0f, 0f, 10f * Time.deltaTime * speed); rotRaft.transform.position = transRaft.transform.position;

        if (!connected || !gameStarted || goalReached || gameFinished || !introPass)
            return;

       
        gameStarted = true;
        cameraObj.transform.Translate(0f, 0f, 10f * Time.deltaTime * speed);
        rotRaft.transform.position = transRaft.transform.position;
        transRaft.transform.Translate(wearableControl.LastSensorFrame.acceleration.value.x * -1f * Time.deltaTime, 0f, 0f);
    }

    public void Restart()
    {
        UnityEngine.SceneManagement.SceneManager.LoadScene(0);
    }

    public void plusPotatoCounter()
    {
        potatosCounted++;
        potatoCounterLabel.text = "x" + potatosCounted;
    }

    public void DecreasePotatoes()
    {
        potatosCounted--;
        potatoCounterLabel.text = "x" + potatosCounted;
    }
    public void ReachGoal()
    {
        gameFinished = true;
        var potatoes = GameObject.FindGameObjectsWithTag("Potato");
        Debug.Log("GOAL REACHED, AMOUNT OF PEAS: " + (potatoes.Length-1));
        potatoCounterLabel.text = "x" + (potatoes.Length - 1);
        potatoCounterPanel.SetActive(true);
    }

    public void intropass()
    {
        introPass = true;
    }

}
